@@ -36,14 +36,7 @@ extern int output_start_y;
 extern int message_visible;
 extern int xterm_hintbar;
 
-#ifdef HAVE_GNOME
-#    define nice_rotating_dash 1
-#    define horizontal_split   0
-#    define xterm_hintbar      0
-#    define message_visible    1
-#else
 extern int horizontal_split;
 extern int nice_rotating_dash;
-#endif
 
 #endif /* __LAYOUT_H */
