@@ -144,7 +144,7 @@
 #include "gsession.h"
 #endif
 
-/* "$Id: main.c,v 1.94 1999/04/21 19:18:51 norbert Exp $" */
+/* "$Id: main.c,v 1.97 1999/06/22 21:02:39 unammx Exp $" */
 
 /* When the modes are active, left_panel, right_panel and tree_panel */
 /* Point to a proper data structure.  You should check with the functions */
@@ -1242,6 +1242,9 @@ static menu_entry PanelMenu [] = {
     { ' ', "", ' ', 0 },		    
     { ' ', N_("&Network link..."),          'N', netlink_cmd },
     { ' ', N_("FT&P link..."),              'P', ftplink_cmd },
+#ifdef WITH_SMBFS
+    { ' ', N_("SM&B link..."),              'B', smblink_cmd },
+#endif
 #endif
     { ' ', "", ' ', 0 },
 #ifdef OS2_NT
@@ -1263,6 +1266,9 @@ static menu_entry RightMenu [] = {
     { ' ', "", ' ', 0 },		    
     { ' ', N_("&Network link..."),       'N', netlink_cmd },
     { ' ', N_("FT&P link..."),           'P', ftplink_cmd },
+#ifdef WITH_SMBFS
+    { ' ', N_("SM&B link..."),           'B', smblink_cmd },
+#endif
 #endif
     { ' ', "", ' ', 0 },
 #ifdef OS2_NT
@@ -2577,6 +2583,9 @@ process_args (int c, const char *option_arg)
 #ifdef USE_NETCODE
     case 'l':
 	ftpfs_set_debug (option_arg);
+#ifdef WITH_SMBFS
+	smbfs_set_debug (option_arg);
+#endif
 	break;
 #endif
 
@@ -2774,7 +2783,7 @@ init_corba_with_args (int *argc, char **argv, poptContext *ctx)
 
 #ifndef HAVE_CORBA
 void
-corba_create_window (void)
+corba_create_window (const char *startup_dir)
 {
 	/* nothing */
 }
@@ -2788,6 +2797,13 @@ handle_args (int argc, char *argv [])
     poptContext   ctx;
 
 #ifdef HAVE_GNOME
+    /* special case, handle --desktop-linksdir without initing X */
+    if (argc > 1){
+	    if (strcmp (argv [1], "--desktop-linksdir") == 0){
+		    puts (DESKTOP_INIT_DIR);
+		    exit (1);
+	    }
+    }
 #ifdef HAVE_CORBA
     init_corba_with_args (&argc, argv, &ctx);
 #else
